netapp_ontap.models.software_mcc API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.software_mcc`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SoftwareMccSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SoftwareMcc object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `elapsed_duration GET`

    Elapsed duration of update time (in seconds) of MetroCluster.

    Example: 2140

  `estimated_duration GET`

    Estimated duration of update time (in seconds) of MetroCluster.

    Example: 3480

  `name GET`

    Name of the site in MetroCluster.

    Example: cluster_A

  `state GET`

    Upgrade state of MetroCluster.

    Valid choices:

    - in_progress
    - waiting
    - paused_by_user
    - paused_on_error
    - completed
    - canceled
    - failed
    - pause_pending
    - cancel_pending